# UI/UX Feedback

**ID:** Feedback-20260302-103456
**URL:** http://127.0.0.1:5858/
**Date:** 2026-03-02 10:35:37

## Selected Elements

- `{'selector': 'button:nth-child(1)', 'parents': ['div#middle-section', 'main.content-area', 'div.content-header', 'div.header-actions.d-flex']}`

## Feedback

the popup menu has been covered  by panel

## Screenshot

![Screenshot](x-ipe-docs/uiux-feedback/Feedback-20260302-103456/page-screenshot.png)
